import { __decorate } from 'tslib';
import { Pipe, NgModule } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';

let HighlightPipe = class HighlightPipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(value, highlightWord, highlightColor) {
        if (!highlightWord) {
            return value;
        }
        const regex = new RegExp(highlightWord, 'gi');
        const match = value.match(regex);
        if (!match) {
            return value;
        }
        if (!highlightColor) {
            highlightColor = 'yellow';
        }
        const html = `<span style="background-color:${highlightColor}; font-weight:bold">${match[0]}</span>`;
        return this.sanitizer.bypassSecurityTrustHtml(value.replace(regex, html));
    }
};
HighlightPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
HighlightPipe = __decorate([
    Pipe({
        name: 'highlight'
    })
], HighlightPipe);

let NgxHighlightTextModule = class NgxHighlightTextModule {
};
NgxHighlightTextModule = __decorate([
    NgModule({
        declarations: [
            HighlightPipe
        ],
        imports: [],
        exports: [HighlightPipe]
    })
], NgxHighlightTextModule);

/*
 * Public API Surface of ngx-highlight-text
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HighlightPipe, NgxHighlightTextModule };
//# sourceMappingURL=ngx-highlight-text.js.map
